'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = getWebpackCommonConfig;

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

var _extractTextWebpackPlugin = require('extract-text-webpack-plugin');

var _extractTextWebpackPlugin2 = _interopRequireDefault(_extractTextWebpackPlugin);

var _caseSensitivePathsWebpackPlugin = require('case-sensitive-paths-webpack-plugin');

var _caseSensitivePathsWebpackPlugin2 = _interopRequireDefault(_caseSensitivePathsWebpackPlugin);

var _fs = require('fs');

var _path = require('path');

var _rucksackCss = require('rucksack-css');

var _rucksackCss2 = _interopRequireDefault(_rucksackCss);

var _autoprefixer = require('autoprefixer');

var _autoprefixer2 = _interopRequireDefault(_autoprefixer);

var _friendlyErrorsWebpackPlugin = require('friendly-errors-webpack-plugin');

var _friendlyErrorsWebpackPlugin2 = _interopRequireDefault(_friendlyErrorsWebpackPlugin);

var _nodeNotifier = require('node-notifier');

var _nodeNotifier2 = _interopRequireDefault(_nodeNotifier);

var _buildStatisticsWebpackPlugin = require('build-statistics-webpack-plugin');

var _buildStatisticsWebpackPlugin2 = _interopRequireDefault(_buildStatisticsWebpackPlugin);

var _bigbrotherWebpackPlugin = require('bigbrother-webpack-plugin');

var _bigbrotherWebpackPlugin2 = _interopRequireDefault(_bigbrotherWebpackPlugin);

var _getBabelCommonConfig = require('./getBabelCommonConfig');

var _getBabelCommonConfig2 = _interopRequireDefault(_getBabelCommonConfig);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint quotes:0 */

function getWebpackCommonConfig(args) {
  var pkgPath = (0, _path.join)(args.cwd, 'package.json');
  var pkg = (0, _fs.existsSync)(pkgPath) ? require(pkgPath) : {};
  var atoolBuildPkg = require((0, _path.join)(__dirname, '../package.json'));

  var jsFileName = args.hash ? '[name]-[chunkhash].js' : '[name].js';
  var cssFileName = args.hash ? '[name]-[chunkhash].css' : '[name].css';
  var commonName = args.hash ? 'common-[chunkhash].js' : 'common.js';

  var silent = args.silent === true;
  var babelOptions = (0, _getBabelCommonConfig2.default)();

  var postcssOptions = {
    sourceMap: true,
    plugins: [(0, _rucksackCss2.default)(), (0, _autoprefixer2.default)({
      browsers: ['last 2 versions', 'Firefox ESR', '> 1%', 'ie >= 8', 'iOS >= 8', 'Android >= 4']
    })]
  };

  var emptyBuildins = ['child_process', 'cluster', 'dgram', 'dns', 'fs', 'module', 'net', 'readline', 'repl', 'tls'];

  var browser = pkg.browser || {};

  var node = emptyBuildins.reduce(function (obj, name) {
    if (!(name in browser)) {
      return _extends({}, obj, _defineProperty({}, name, 'empty'));
    }
    return obj;
  }, {});

  // 时间分析产物文件地址
  var stagesPath = (0, _path.join)(__dirname, 'build-statistics/compilation.json');

  var config = {
    babel: babelOptions,
    postcss: postcssOptions,

    output: {
      path: (0, _path.join)(process.cwd(), './dist/'),
      filename: jsFileName,
      chunkFilename: jsFileName
    },

    devtool: args.devtool,

    resolve: {
      modules: ['node_modules', (0, _path.join)(__dirname, '../node_modules')],
      extensions: ['.web.tsx', '.web.ts', '.web.jsx', '.web.js', '.ts', '.tsx', '.js', '.jsx', '.json']
    },

    entry: pkg.entry,

    node: node,

    module: {
      noParse: [/moment.js/],
      rules: [{
        test: /\.woff(\?v=\d+\.\d+\.\d+)?$/,
        loader: 'url-loader',
        options: {
          limit: 10000,
          minetype: 'application/font-woff'
        }
      }, {
        test: /\.woff2(\?v=\d+\.\d+\.\d+)?$/,
        loader: 'url-loader',
        options: {
          limit: 10000,
          minetype: 'application/font-woff'
        }
      }, {
        test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/,
        loader: 'url-loader',
        options: {
          limit: 10000,
          minetype: 'application/octet-stream'
        }
      }, { test: /\.eot(\?v=\d+\.\d+\.\d+)?$/,
        loader: 'url-loader',
        options: {
          limit: 10000,
          minetype: 'application/vnd.ms-fontobject'
        }
      }, {
        test: /\.svg(\?v=\d+\.\d+\.\d+)?$/,
        loader: 'url-loader',
        options: {
          limit: 10000,
          minetype: 'image/svg+xml'
        }
      }, {
        test: /\.(png|jpg|jpeg|gif)(\?v=\d+\.\d+\.\d+)?$/i,
        loader: 'url-loader',
        options: {
          limit: 10000
        }
      }, {
        test: /\.html?$/,
        loader: 'file-loader',
        options: {
          name: '[name].[ext]'
        }
      }]
    },

    plugins: [new _webpack2.default.optimize.CommonsChunkPlugin({
      name: 'common',
      filename: commonName
    }), new _extractTextWebpackPlugin2.default({
      filename: cssFileName,
      disable: false,
      allChunks: true
    }), new _caseSensitivePathsWebpackPlugin2.default(), new _buildStatisticsWebpackPlugin2.default({
      path: stagesPath
    }), new _bigbrotherWebpackPlugin2.default({
      cwd: process.cwd(),
      tool: {
        name: 'atool-build',
        version: atoolBuildPkg.version,
        stagesPath: stagesPath
      }
    }), new _friendlyErrorsWebpackPlugin2.default({
      onErrors: function onErrors(severity, errors) {
        if (silent) return;
        if (severity !== 'error') {
          _nodeNotifier2.default.notify({
            title: 'ant tool',
            message: 'warn',
            contentImage: (0, _path.join)(__dirname, '../assets/warn.png'),
            sound: 'Glass'
          });
          return;
        }
        var error = errors[0];
        _nodeNotifier2.default.notify({
          title: 'ant tool',
          message: severity + ' : ' + error.name,
          subtitle: error.file || '',
          contentImage: (0, _path.join)(__dirname, '../assets/fail.png'),
          sound: 'Glass'
        });
      }
    })]
  };

  return config;
}
module.exports = exports['default'];